@@ -65,7 +65,7 @@
 #'   \code{\link{print.amlps}}. Fitted smooth terms can be visualized with the
 #'   \code{\link{plot.amlps}} routine.
 #'
-#' @author Gressani Oswaldo \email{oswaldo_gressani@hotmail.fr}.
+#' @author Oswaldo Gressani \email{oswaldo_gressani@hotmail.fr}.
 #'
 #' @seealso \code{\link{cubicbs}}, \code{\link{amlps.object}},
 #'  \code{\link{print.amlps}}, \code{\link{plot.amlps}}
@@ -89,11 +89,11 @@
 #' @references Gressani, O. and Lambert, P. (2018). Fast Bayesian inference
 #'  using Laplace approximations in a flexible promotion time cure model based
 #'  on P-splines. \emph{Computational Statistical & Data Analysis} \strong{124}:
-#'  151-167. \url{https://doi.org/10.1016/j.csda.2018.02.007}
+#'  151-167.
 #' @references Opsomer, J. D. and Ruppert, D. (1999). A root-n consistent
 #'  backfitting estimator for semiparametric additive modeling. \emph{Journal of
 #'  Computational and Graphical Statistics}, \strong{8}(4): 715-732.
-#'  \url{https://doi.org/10.1080/10618600.1999.10474845}
+#'
 #'
 #' @export
 
@@ -620,7 +620,7 @@ amlps <- function(formula, data, K = 30, penorder = 2, cred.int = 0.95){
   matdiagH <- matrix(0, nrow = nv.sample, ncol = H)
 
   for (s in 1:nv.sample) {
-    if(class(try(diagHmatrix(v.sample[s, ]), silent = TRUE)) == "numeric") {
+    if(is.numeric(try(diagHmatrix(v.sample[s, ]), silent = TRUE))) {
       matdiagH[s, ] <- diagHmatrix(v.sample[s, ])
     } else {
       matdiagH[s, ] <- diagHmatrix(v.max)
