@@ -31,6 +31,8 @@
 #'  basis. The default is NULL, so that the B-spline basis is specified
 #'  in the interval \emph{[0, tup]}, where \emph{tup} is the upper bound of
 #'  the follow-up times. It is required that \emph{tmax} > \emph{tup}.
+#' @param constr Constraint imposed on last B-spline coefficient
+#'  (default is 6).
 #'
 #' @details The log-baseline hazard is modeled as a linear combination of
 #'   \code{K} cubic B-splines as obtained from \code{\link{cubicbs}}. A
@@ -81,7 +83,7 @@
 #' plot.cred = FALSE, ylim = c(0,1))
 #' par(opar)
 #'
-#' @author Gressani Oswaldo \email{oswaldo_gressani@hotmail.fr}.
+#' @author Oswaldo Gressani \email{oswaldo_gressani@hotmail.fr}.
 #'
 #' @seealso \code{\link{curelps.object}}, \code{\link{curelps.extract}},
 #'  \code{\link{plot.curelps}}, \code{\link{print.curelps}},
@@ -89,22 +91,22 @@
 #'
 #' @references Cox, D.R. (1972). Regression models and life-tables.
 #'   \emph{Journal of the Royal Statistical Society: Series B (Methodological)}
-#'   \strong{34}(2): 187-202. \url{https://doi.org/10.1111/j.2517-6161.1972.tb00899.x}
+#'   \strong{34}(2): 187-202.
 #' @references Bremhorst, V. and Lambert, P. (2016). Flexible estimation in
 #'   cure survival models using Bayesian P-splines.
 #'   \emph{Computational Statistical & Data Analysis} \strong{93}: 270-284.
-#'   \url{https://doi.org/10.1016/j.csda.2014.05.009}
 #' @references Gressani, O. and Lambert, P. (2018). Fast Bayesian inference
 #'   using Laplace approximations in a flexible promotion time cure model based
 #'   on P-splines. \emph{Computational Statistical & Data Analysis} \strong{124}:
-#'   151-167. \url{https://doi.org/10.1016/j.csda.2018.02.007}
+#'   151-167.
 #' @references Lambert, P. and Bremhorst, V. (2019). Estimation and
 #'   identification issues in the promotion time cure model when the same
 #'   covariates influence long- and short-term survival. \emph{Biometrical
-#'   Journal} \strong{61}(2): 275-289. \url{https://doi.org/10.1002/bimj.201700250}
+#'   Journal} \strong{61}(2): 275-289.
 #' @export
 
-curelps <- function(formula, data, K = 30, penorder = 2, tmax = NULL){
+curelps <- function(formula, data, K = 30, penorder = 2, tmax = NULL,
+                    constr = 6){
 
   if (!inherits(formula, "formula"))
     stop("Incorrect model formula")
@@ -143,7 +145,7 @@ curelps <- function(formula, data, K = 30, penorder = 2, tmax = NULL){
     for (j in 3:ncol(mff)) {
       col.pos <- match(1, as.numeric(colnames(mff[j]) == colnames(mff)))
 
-      if (class(mff[, col.pos]) == "factor") {
+      if (is.factor(class(mff[, col.pos]))) {
         if (grepl(colnames(mff)[col.pos], lt.vars, fixed = TRUE)) {
           ncovar.lt <- ncovar.lt + (nlevels(mff[, col.pos]) - 1)
           lt.vars <- gsub(colnames(mff)[col.pos], replacement = "", lt.vars)
@@ -185,7 +187,7 @@ curelps <- function(formula, data, K = 30, penorder = 2, tmax = NULL){
     for (j in 3:ncol(mff)) {
       col.pos <- match(1, as.numeric(colnames(mff[j]) == colnames(data)))
 
-      if (class(data[, col.pos]) == "factor") {
+      if (is.factor(class(data[, col.pos]))) {
         if (grepl(colnames(data)[col.pos], lt.vars, fixed = TRUE)) {
           ncovar.lt <- ncovar.lt + (nlevels(data[, col.pos]) - 1)
           lt.vars <-
@@ -257,7 +259,7 @@ curelps <- function(formula, data, K = 30, penorder = 2, tmax = NULL){
   H <- K + nbeta + ngamma    # Latent field dimension
   if(n < H)
     warning("Number of coefficients to be estimated is larger than sample size")
-  constr <- 6                # Constraint on last B-spline coefficient
+  constr <- constr                # Constraint on last B-spline coefficient
   penorder <- floor(penorder)
   if(penorder < 2 || penorder > 3)
     stop("Penalty order must be either 2 or 3")
@@ -538,10 +540,10 @@ curelps <- function(formula, data, K = 30, penorder = 2, tmax = NULL){
     Laplace <- Laplace.approx(latent0, v)
 
     # Output of Laplace approximation
-    Sigmastar <- Laplace$Sigmastar # Unconstrained latent  covariance matrix
-    Sigstar.c <- Laplace$Sigstar.c # Constrained covariance matrix
-    latstar <- Laplace$latstar     # Unconstrained mode of Laplace approx.
-    latstar.c <- Laplace$latstar.c # Constrained mode of dimension H-1
+    Sigmastar <- Laplace$Sigmastar   # Unconstrained latent  covariance matrix
+    Sigstar.c <- Laplace$Sigstar.c   # Constrained covariance matrix
+    latstar <- Laplace$latstar       # Unconstrained mode of Laplace approx.
+    latstar.c <- Laplace$latstar.c   # Constrained mode of dimension H-1
     latstar.cc <- Laplace$latstar.cc # Constrained mode of dimension H
 
     # Computation of the log-posterior of v
@@ -636,7 +638,11 @@ curelps <- function(formula, data, K = 30, penorder = 2, tmax = NULL){
       v.grid <- rev(v.grid)
       logpv.v <- rev(logpv.v)
 
-      vmap <- (v.grid[1] + v.grid[3]) / 2
+      if (length(v.grid) >= 3) {
+        vmap <- (v.grid[1] + v.grid[3]) / 2
+      } else{
+        vmap <- (v.grid[1] + v.grid[2]) / 2
+      }
       logpvmap <- logpost.v(vmap, latent0)$y
       nquad <- 8
       left.step.j  <- (-1)
